pub enum ConformanceFailure {
ReturnedError(String),
EmptyCentralSection,
IncorrectEvidence,
NonDeterministic,
WrongContourCount {
case: &'static str,
expected: usize,
actual: usize,
},
WrongSectionArea {
case: &'static str,
expected: f64,
actual: f64,
},
TangentPlaneHasArea {
case: &'static str,
area: f64,
},
}Variants
ReturnedError(String)
EmptyCentralSection
IncorrectEvidence
NonDeterministic
WrongContourCount
A section returned the wrong number of closed contours.
WrongSectionArea
A section contour enclosed the wrong area.
TangentPlaneHasArea
A plane tangent to the solid produced interior area instead of touching it.