pub struct SectionEvidence {
pub source: SectionSource,
pub source_triangles: usize,
pub output_vertices: usize,
pub output_contours: usize,
}Expand description
Auditable counts for one section operation.
Fields
source: SectionSourceApproximation source.
source_triangles: usizeSource triangles inspected.
output_vertices: usizeOutput contour vertices.
output_contours: usizeOutput contours.
Implementations
Sourceimpl SectionEvidence
impl SectionEvidence
Sourcepub const fn input_mesh(
source_triangles: usize,
output_vertices: usize,
output_contours: usize,
) -> Self
pub const fn input_mesh( source_triangles: usize, output_vertices: usize, output_contours: usize, ) -> Self
Record evidence for a section derived from the input mesh.
Sourcepub const fn is_derived_from_input_mesh(self) -> bool
pub const fn is_derived_from_input_mesh(self) -> bool
Whether this result came from the discrete input mesh.